@@ -50,8 +50,8 @@ from .core import (
     UserRootInfo,
     TeamRootInfo,
     FullAccount,
-    TeamSpaceUsage,
     SpaceUsage,
+    PersonalSpaceUsage,
     WriteMode,
     Metadata,
     DeletedMetadata,
@@ -611,12 +611,10 @@ class DropboxClient:
     # ---- SDK wrappers ----------------------------------------------------------------
 
     @overload
-    def get_account_info(self, dbid: None = None) -> FullAccount:
-        ...
+    def get_account_info(self, dbid: None = None) -> FullAccount: ...
 
     @overload
-    def get_account_info(self, dbid: str) -> Account:
-        ...
+    def get_account_info(self, dbid: str) -> Account: ...
 
     def get_account_info(self, dbid: str | None = None) -> Account:
         """
@@ -657,7 +655,7 @@ class DropboxClient:
 
         return self._cached_account_info
 
-    def get_space_usage(self) -> SpaceUsage:
+    def get_space_usage(self) -> PersonalSpaceUsage:
         """
         :returns: The space usage of the currently linked account.
         """
@@ -781,20 +779,18 @@ class DropboxClient:
                             "Data corrupted", "Please retry download."
                         )
 
-                    # Dropbox SDK provides naive datetime in UTC.
-                    client_mod = md.client_modified.replace(tzinfo=timezone.utc)
-                    server_mod = md.server_modified.replace(tzinfo=timezone.utc)
+            # Dropbox SDK provides naive datetime in UTC.
+            client_mod = md.client_modified.replace(tzinfo=timezone.utc)
+            server_mod = md.server_modified.replace(tzinfo=timezone.utc)
 
-                    # Enforce client_modified < server_modified.
-                    now = time.time()
-                    mtime = min(client_mod.timestamp(), server_mod.timestamp(), now)
-                    # Set mtime of downloaded file.
-                    if os.utime in os.supports_fd:
-                        os.utime(f.fileno(), (now, mtime))
-                    elif os.utime in os.supports_follow_symlinks:
-                        os.utime(local_path, (now, mtime), follow_symlinks=False)
-                    else:
-                        os.utime(local_path, (now, mtime))
+            # Enforce client_modified < server_modified.
+            now = time.time()
+            mtime = min(client_mod.timestamp(), server_mod.timestamp(), now)
+            # Set mtime of downloaded file.
+            if os.utime in os.supports_follow_symlinks:
+                os.utime(local_path, (now, mtime), follow_symlinks=False)
+            else:
+                os.utime(local_path, (now, mtime))
 
         return convert_metadata(md)
 
@@ -1662,7 +1658,7 @@ def convert_full_account(res: users.FullAccount) -> FullAccount:
     )
 
 
-def convert_space_usage(res: users.SpaceUsage) -> SpaceUsage:
+def convert_space_usage(res: users.SpaceUsage) -> PersonalSpaceUsage:
     if res.allocation.is_team():
         team_allocation = res.allocation.get_team()
         if team_allocation.user_within_team_space_allocated == 0:
@@ -1670,16 +1666,16 @@ def convert_space_usage(res: users.SpaceUsage) -> SpaceUsage:
             allocated = team_allocation.allocated
         else:
             allocated = team_allocation.user_within_team_space_allocated
-        return SpaceUsage(
+        return PersonalSpaceUsage(
             res.used,
             allocated,
-            TeamSpaceUsage(team_allocation.used, team_allocation.allocated),
+            SpaceUsage(team_allocation.used, team_allocation.allocated),
         )
     elif res.allocation.is_individual():
         individual_allocation = res.allocation.get_individual()
-        return SpaceUsage(res.used, individual_allocation.allocated, None)
+        return PersonalSpaceUsage(res.used, individual_allocation.allocated, None)
     else:
-        return SpaceUsage(res.used, 0, None)
+        return PersonalSpaceUsage(res.used, 0, None)
 
 
 def convert_metadata(res):  # type:ignore[no-untyped-def]
